package com.sxc.etaxincome.controller;

import com.sxc.etaxincome.criteria.IncomeQueryCriteria;
import com.sxc.etaxincome.domain.business.IQueryManager;
import com.sxc.etaxincome.domain.command.query.IQueryCommand;
import com.sxc.etaxincome.domain.command.query.IQueryPageListCommand;
import com.sxc.etaxincome.domain.model.common.CommonRequestWrapper;
import com.sxc.etaxincome.domain.model.common.CommonResponse;
import com.sxc.etaxincome.domain.model.common.PageList;
import com.sxc.etaxincome.domain.model.report.IReportResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @author caosongqing
 * @date 2024/4/24
 * @description
 */
@Slf4j
@RestController
@RequestMapping("/query")
public class QueryController {

    @Autowired
    @Qualifier(value = "queryCancelListQueryPageListCommand")
    private IQueryPageListCommand queryCancelListQueryPageListCommand;

    @Autowired
    @Qualifier(value = "queryReportListQueryPageListCommand")
    private IQueryPageListCommand queryReportListQueryPageListCommand;

    @Autowired
    @Qualifier(value = "queryReportItemQueryCommand")
    private IQueryCommand queryReportItemQueryCommand;

    @Autowired
    @Qualifier(value = "queryManager")
    private IQueryManager queryManager;

    @PostMapping("/cancel-list")
    public CommonResponse<PageList<IReportResponse>> queryCancelList(@Validated CommonRequestWrapper commonRequestWrapper) {
        return queryCancelListQueryPageListCommand.execute(commonRequestWrapper);
    }

    @PostMapping("/cancel-list/json")
    public CommonResponse<PageList<IReportResponse>> queryCancelListJson(@Validated @RequestBody CommonRequestWrapper requestCommonWrapper) {
        return queryCancelListQueryPageListCommand.execute(requestCommonWrapper);
    }

    @PostMapping("/report-list")
    public CommonResponse<PageList<IReportResponse>> queryReportList(@Validated CommonRequestWrapper commonRequestWrapper) {
        return queryReportListQueryPageListCommand.execute(commonRequestWrapper);
    }

    @PostMapping("/report-list/json")
    public CommonResponse<PageList<IReportResponse>> queryReportListJson(@Validated @RequestBody CommonRequestWrapper requestCommonWrapper) {
        return queryReportListQueryPageListCommand.execute(requestCommonWrapper);
    }

    @PostMapping("/report-item")
    public CommonResponse<IReportResponse> queryReportItem(@Validated CommonRequestWrapper commonRequestWrapper) {
        return queryReportItemQueryCommand.execute(commonRequestWrapper);
    }

    @PostMapping("/report-item/json")
    public CommonResponse<IReportResponse> queryReportItemJson(@Validated @RequestBody CommonRequestWrapper requestCommonWrapper) {
        return queryReportItemQueryCommand.execute(requestCommonWrapper);
    }

    @PostMapping("/page-list/order-by-updateTime-desc")
    public String queryPageListOrderByUpdateTimeDesc(@RequestBody IncomeQueryCriteria incomeQueryCriteria) {
        return queryManager.queryPageListOrderByUpdateTimeDesc(incomeQueryCriteria);
    }

    @GetMapping("/complete-period/apply-id")
    public String completePeriodWithApplyId(Long applyId) {
        return queryManager.completePeriod(applyId);
    }
}
