package com.sxc.etaxincome.domain.template;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.sxc.etaxincome.domain.model.common.CommonResponse;
import com.sxc.etaxincome.enums.ResponseCode;
import com.sxc.framework.common.json.JSONUtil;

import com.sxc.etaxincome.domain.constants.EtaxReportConstants;

import lombok.extern.slf4j.Slf4j;

/**
 * handle response result
 * @author caosongqing
 * @date 2022/11/29
 * @description
 */
@Slf4j
public abstract class ResponseHandlerTemplate<T> {
    public CommonResponse<T> handle(String response) {
        if (!JSONUtil.isJSONObject(response)) {
            return CommonResponse.error(ResponseCode.ERROR);
        }
        CommonResponse<T> responseCommon;
        JSONObject jsonObject = JSON.parseObject(response);
        String responseCode = jsonObject.getString(EtaxReportConstants.ETAX_RESPONSE_CODE_KEY);
        if (EtaxReportConstants.ETAX_SUCCESS_CODE.equals(responseCode)) {
            responseCommon = this.handleSuccess(jsonObject);
        } else if (EtaxReportConstants.ETAX_ERROR_CODE.equals(responseCode)) {
            String errorMessage = jsonObject.getString(EtaxReportConstants.ETAX_RESPONSE_MESSAGE_KEY);
            responseCommon = CommonResponse.error(errorMessage);
            this.handleError(errorMessage);
        } else if (EtaxReportConstants.ETAX_ERROR_INVALID_TOKEN.equals(responseCode)) {
            responseCommon = CommonResponse.error(ResponseCode.TOKEN_INVALID);
        } else {
            String errorMessage = jsonObject.getString(EtaxReportConstants.ETAX_RESPONSE_MESSAGE_KEY);
            responseCommon = CommonResponse.error(responseCode, errorMessage);
            this.handleError(errorMessage);
        }
        return responseCommon;
    }

    protected abstract CommonResponse<T> handleSuccess(JSONObject jsonObject);

    protected void handleError(String errorMessage) {
        log.info("response errorMessage:{}", errorMessage);
    }
}
